<?php 
namespace Teknisa\MAN\Controllers\DataExporterImpl;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\DataExporter\Service\DataExporter as DataExporter;
use Zeedhi\DataExporter\Utility\ReportInfoManager;
use Zeedhi\Framework\DataSource\FilterCriteria as FilterCriteria;

class RMReportController {
    protected $dataExporter;
    protected $reportHandlerFactory;
    protected $reportInfoManager;
    
    public function __construct ($reportHandlerFactory, DataExporter $dataExporter, ReportInfoManager $reportInfoManager) {
        $this->reportHandlerFactory = $reportHandlerFactory;
        $this->dataExporter = $dataExporter;
        $this->reportInfoManager = $reportInfoManager;
    }
    
    private function generateReport ($request, $response, $exportFormat) {
        try {
            $params = $request->getParameters();
            $dataSourceName = $params['dataSourceName'];
            $metadata = $params['metaData'];
            $metadata['dbType'] = "SQL";
            
            $reportHandler = $this->reportHandlerFactory->getReportHandler($dataSourceName);
            if(!empty($reportHandler)) {
                $result = $reportHandler->buildNewRequest($request, $response);
                $newRequest = $result[0]; 
                $response   = $result[1];
            } else {
                $newRequest = $request;
            }
            $filterCriteria = $newRequest->getFilterCriteria();
            
            $fileName = $this->dataExporter->createExportFile($filterCriteria, $metadata, $exportFormat);
            $message = $this->getMessage($fileName, $metadata);
            $response->addMessage(new Response\Message($message));
        } catch (\Exception $e) {
            $response->setError(new Response\Error("A unexpected error occurred: {$e->getMessage()}", $e->getCode(), $e->getTraceAsString()));
        }
    }

    
    protected function getMessage($fileName, $metadata) {
        $row = array("fileName"=>$fileName, "title"=>$metadata['title']);
        $key = $this->reportInfoManager->save($row);
        return "/Report?requestType=Row&row[KEY]=".$key;
    }
    
    public function createDataExportPDFFile($request, Response $response) {
        $this->generateReport($request, $response, DataExporter::EXPORT_FORMAT_REPORT);
    }
    
    public function createDataExportXLSFile($request, Response $response) {
        $this->generateReport($request, $response, DataExporter::EXPORT_FORMAT_SPREADSHEET);   
    }
}       