<?php
namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Services\ListaProdutosService;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;

class ListaProdutos extends CrudWithParameterBag {

    protected $listaProdutos1 = 'listaprodutoscliente';
    protected $listaProdutos2 = 'produtosinsertwzd'; //datasource para mostrar os produtos "adicionados"
    protected $listaProdutosSelect = 'listaProdutosSelect';
    protected $listaProdutosSelectSemNivel = 'listaProdutosSelectSemNivel';
    protected $dataSourceName = 'listaProdutosSalvar';
    protected $dataSourceNameUltatu = 'listaProdutosUltatu';

    /**
     * @var ListaProdutosService
     */
    protected $ListaProdutosService;
    protected $parameterBagColumns = array('NRORG', 'CDPRODUTO', 'NRSEQRELACCATEGORIACONFIGURAC', 'CDNVPRODUTO');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, ListaProdutosService $listaProdutos) {
        $this->listaProdutos = $listaProdutos;
        parent::__construct($dataSourceManager, $parameterBag);
    }
    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        foreach ($request->getDataSet()->getRows() as $row) {
            $arrayCodigoProduto = $row['PRODLIST'];
            $row['CDOPERINCLUSAO'] = $row['CDOPERADOR'];
            $row['NRORGINCLUSAO'] = $row['NRORG'];
            $row['DTINCLUSAO'] = date("d/m/Y H:i:s");
            $row['IDATIVO'] = 'S';
            foreach ($arrayCodigoProduto as $produto) {
                $row['CDPRODUTO'] = $produto;
                $row['__is_new'] = true;
                $row['changed'] = false;
                $row['NRSEQRELACPRODCATEGORIA'] = $this->listaProdutos->getNextId();
                $this->dataSourceManager->persist(new DataSet($this->dataSourceName, array($row)));
            }
        }
        $response->addNotification(new Notification("Dados inseridos com sucesso!", Notification::TYPE_SUCCESS));
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        // $filterData = $request->getFilterCriteria();
        // $filterData->setDataSourceName($this->listaProdutos1);
        // $dataSet = $this->dataSourceManager->findBy($filterData);
        // $response->addDataSet($dataSet);
        $trazerProdutos = false;
        $filterCriteria = $request->getFilterCriteria();
        $this->dataSourceName = $this->listaProdutos1;
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if($columnName == 'CDPRODUTO') {
                $this->dataSourceName = $this->listaProdutos2;
                parent::find($request, $response);
            }
            if($columnName == 'NRSEQRELACCATEGORIACONFIGURAC') {
                $trazerProdutos = true;
            }
        }
        if($trazerProdutos)
            parent::find($request, $response);
    }

    public function findSelect(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->listaProdutosSelect;
        $this->parameterBagColumns = array("CDPRODUTO","CDFAMILISALD","CDNVPRODUTO","NRORG","CDFILIAL","CDCONSUMIDOR","CDCLIENTE");
        parent::find($request, $response);
    }

    public function findSelectSemNivel(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->listaProdutosSelectSemNivel);
        $dataSet = $this->dataSourceManager->findBy($filterData);
        $response->addDataSet($dataSet);
    }

    public function delete (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as $row) {
                $row['DTULTATU'] = date("d/m/Y H:i:s");
                $row['CDOPERULTATU'] = $row['CDOPERADOR'];
                $row['NRORGULTATU'] = $row['NRORG'];
                $row['IDATIVO'] = 'N';
                $this->dataSourceManager->persist(new DataSet($this->dataSourceNameUltatu, array($row)));
            }
            $response->addNotification(new Notification("Dados excluídos com sucesso!", Notification::TYPE_SUCCESS));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}