<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Utilities;

class RelDescConcedidos extends CrudWithParameterBag{

    const RELATORIO = 'vnd55007_relDescConcedidos';
    
    protected $utilService;
    protected $dataSourceName;
    
    protected $parameterBagColumns = array('CDFILIAL', 'TIPORELATORIO', 'DTINI', 'DTFIM');
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Utilities\Util $utilService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
    }
    
    
    public function relDesconto(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        $this->dataSourceName = self::RELATORIO;
        
        $dataSourceFilter          = self::prepareParameters($conditions);
        $requestDataSourceFilter = $request->getFilterCriteria()->getConditions();
        
        foreach($requestDataSourceFilter as $filter) {
            if($filter['operator'] === 'MAPPED_LIKE_ALL') {
                array_push($dataSourceFilter, $filter);
            }
        }
        
        //Retirada pagination
        $newRequest = new DTO\Request\Filter(
            new FilterCriteria(
                $this->dataSourceName,
                $dataSourceFilter,
                //$request->getFilterCriteria()->getPage()
                null,
                null
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        parent::find($newRequest, $response);
    }
    
    private function prepareParameters($conditions) {
        if(isset($conditions['DTENTRVENDA'])) {
            $DTINI = $conditions['DTENTRVENDA'][0];
            $DTFIM = $conditions['DTENTRVENDA'][1];
        } else {
            $DTFIM = $DTINI = NULL;
        }
        
       $parameters = array(
            'CDFILIAL'  => $conditions['CDFILIAL'],
            'TIPORELATORIO'   => $conditions['TIPORELATORIO'],
            'DTINI'     => $DTINI,
            'DTFIM'     => $DTFIM
        );
        
        $dataSourceFilter = array();
        
        $dataSourceFilter[0] = array(
            "columnName" => 'CDFILIAL',
            "operator"   => "=",
            "value"      => $parameters['CDFILIAL']
        ); 
        $dataSourceFilter[1] = array(
            "columnName" => 'TIPORELATORIO',
            "operator"   => "=",
            "value"      => $parameters['TIPORELATORIO']
        );
        $dataSourceFilter[5] = array(
            "columnName" => 'DTINI',
            "operator"   => "=",
            "value"      => $parameters['DTINI']
        );
        $dataSourceFilter[6] = array(
            "columnName" => 'DTFIM',
            "operator"   => "=",
            "value"      => $parameters['DTFIM']
        );
        
        return $dataSourceFilter;
    }
}