<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;


class SMTPManagement extends CrudWithParameterBag {

    const DEFAULT_ERROR_MSG     = 'Ocorreu um erro inesperado. Favor conferir a sua configuração de SMTP. Segue um log do erro :';
    const DEFAULT_SUCCESS_MSG   = 'Email enviado. Verifique a caixa de entrada do email informado.';
    const DATA_SOURCE_SMTP      = 'vnd10003_paramGerais_configuracoesSMTP';
    
    protected $parameterBagColumns = array('NRORG');
    protected $dataSourceName = "smtp";
    protected $SMTPService;


	public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Services\SMTPManagement $SMTPService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->SMTPService = $SMTPService;
    }

    public function save (Request\DataSet $request, Response $response){
        $dataSet = $request->getDataSet();
        $saveLog = Array();

        foreach ($dataSet->getRows() as &$row) {
            $row['__is_new'] = false;
            $row['changed'] = true;
        }
        try {
            $dataSet->setDataSourceName($this->dataSourceName);
            $this->dataSourceManager->persist($dataSet);
            $saveLog['STATUS'] = true;
        } catch (Exception $e) {
            $saveLog['STATUS'] = false;
        }
        $response->addDataSet(new DataSet('smtp', Array($saveLog)));
    }
    
    public function findSMTP(Request\Filter $request, Response $response){
        $this->parameterBagColumns = array('NRORG');
        $this->dataSourceName = self::DATA_SOURCE_SMTP;
        parent::find($request,$response);
    }
    
    public function saveSMTP(Request\DataSet $request, Response $response){
        $this->dataSourceName = self::DATA_SOURCE_SMTP;
        $this->parameterBagColumns = array('NRORG');
         
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
            $nrPersistedRows = count($persistedRows);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function testaSMTP(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $EMAIL  = $row[0]['email'];
            
            $EMAIL = strtolower($EMAIL);

	        $subject  = 'Teste SMTP - Manage Teknisa';
	        $sender = 'Manage - Odhen';
	        $content =
		        '<p>Teste de configuração de SMTP do Odhen Manage.</p>'.
	            '<p>Se não requisitou este teste, ignore essa mensagem.</p>'.
	            '<p>Email enviado para: '. $EMAIL . '<br>';
            $this->SMTPService->sendEmail($EMAIL, $EMAIL, $sender, $subject, $content);
            $response->setStatus(Response::STATUS_SUCCESS);
            $response->addMessage(new Message(SMTPManagement::DEFAULT_SUCCESS_MSG));
        } catch (\Exception $e) {
            $message = $e->getMessage();
            $response->setStatus(Response::STATUS_WARNING);
            $response->addMessage(new Message(SMTPManagement::DEFAULT_ERROR_MSG));
            $response->addMessage(new Message($message));
        }
    }

}